IndicatorModel class

Model that encapsulates all possible configuration for a tab indicator.

Constructors

IndicatorModel({TabIndicatorType type = TabIndicatorType.underline, Color? color, double? thickness = 2, double? radius, BoxShape? shape, double? verticalPadding, Gradient? gradient, Decoration? customDecoration, EdgeInsetsGeometry? padding, TabIndicatorPosition position = TabIndicatorPosition.bottom, CustomPainter customPainterBuilder(Size size, TextDirection? direction)?})
const

Properties

color Color?
final
customDecoration Decoration?
final
customPainterBuilder CustomPainter Function(Size size, TextDirection? direction)?
Builder for a custom painter. Provides the size and textDirection.
final
gradient Gradient?
final
hashCode int
The hash code for this object.
no setterinherited
padding EdgeInsetsGeometry?
final
position TabIndicatorPosition
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape BoxShape?
final
thickness double?
final
type TabIndicatorType
final
verticalPadding double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited