TabAnimationModel class

Constructors

TabAnimationModel({bool enabled = true, TabAnimationType animationType = TabAnimationType.scale, double? scaleFactor = 1.2, Duration? duration = const Duration(milliseconds: 250), Color? selectedColor, Color? unselectedColor, EdgeInsets? selectedPadding, EdgeInsets? unselectedPadding, Curve? curve = Curves.easeInOut, Curve? scaleCurve = Curves.easeInOut, Curve? opacityCurve = Curves.easeInOut, Curve? containerCurve = Curves.easeInOut, WrapperType? selectedWrapperType, WrapperModel? selectedWrapperModel, WrapperType? unselectedWrapperType, WrapperModel? unselectedWrapperModel})
const

Properties

animationType TabAnimationType
final
containerCurve Curve?
final
curve Curve?
final
duration Duration?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
opacityCurve Curve?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleCurve Curve?
final
scaleFactor double?
final
selectedColor Color?
final
selectedPadding EdgeInsets?
final
selectedWrapperModel WrapperModel?
final
selectedWrapperType WrapperType?
Wrappers for selected state
final
unselectedColor Color?
final
unselectedPadding EdgeInsets?
final
unselectedWrapperModel WrapperModel?
final
unselectedWrapperType WrapperType?
Wrappers for unselected state
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited