SimpleTabModel class

Inheritance

Constructors

SimpleTabModel({IconData? icon, String? label, TabType? tabType, double spacing = 4, double? height})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double?
finalinherited
icon IconData?
final
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
finalinherited
tabType TabType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited