StackPositionedTabBarScreen class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- StackPositionedTabBarScreen
- Available extensions
Constructors
-
StackPositionedTabBarScreen({Key? key, required List<
Widget> pages, required TabWidgetBuilder tabBarBuilder, int? initialIndex, void onTabChanged(int)?, TabBarCubit? tabBarCubit, Widget? drawer, List<Widget> ? fabButtons, FloatingActionButtonLocation? floatingActionButtonLocation, double? top, double? bottom = 0, double? left = 0, double? right = 0}) -
const
Properties
- bottom → double?
-
final
-
final
- drawer → Widget?
-
final
-
fabButtons
→ List<
Widget> ? -
final
- floatingActionButtonLocation → FloatingActionButtonLocation?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialIndex → int?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- left → double?
-
final
- onTabChanged → void Function(int)?
-
final
-
pages
→ List<
Widget> -
final
- right → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabBarBuilder → TabWidgetBuilder
-
final
- tabBarCubit → TabBarCubit?
-
final
- top → double?
-
Position config for the tab bar inside Stack
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
let<
T> (T transformation(Widget)) → T? -
Available on Widget?, provided by the WidgetExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited