TabAnimator class

Inheritance
Available extensions

Constructors

TabAnimator({Key? key, required Widget child, required bool selected, WrapperType? selectedWrapperType, WrapperModel? selectedWrapperModel, WrapperType? unselectedWrapperType, WrapperModel? unselectedWrapperModel, bool? animate = true, Duration duration = const Duration(milliseconds: 250), double scaleFactor = 1.1, Color? selectedColor, Color? unselectedColor, EdgeInsets? selectedPadding, EdgeInsets? unselectedPadding, Curve? scaleCurve, Curve? opacityCurve, Curve? containerCurve})
const

Properties

animate bool?
Enable/disable animations
final
child Widget
finalinherited
containerCurve Curve?
final
duration Duration
Animation duration
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
opacityCurve Curve?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleCurve Curve?
Optional animation curves
final
scaleFactor double
Scale factor when selected
final
selected bool
finalinherited
selectedColor Color?
Optional colors
final
selectedPadding EdgeInsets?
Optional padding
final
selectedWrapperModel WrapperModel?
finalinherited
selectedWrapperType WrapperType?
finalinherited
unselectedColor Color?
final
unselectedPadding EdgeInsets?
final
unselectedWrapperModel WrapperModel?
finalinherited
unselectedWrapperType WrapperType?
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildWrapperChild() Widget
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
let<T>(T transformation(Widget)) → T?

Available on Widget?, provided by the WidgetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited