BaseTab class abstract

Abstract base for all Tab widgets with optional wrapper styling.

Inheritance
Implementers
Available extensions

Constructors

BaseTab({Key? key, String? label, WrapperModel? wrapperModel, double? height, bool? rotate, int? rotateTurns})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double?
Custom builder to wrap the child if you don’t want to use wrapperType. Optional height of the tab (passed to the Tab widget).
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Optional text label for the tab.
final
rotate bool?
Whether to rotate the tab content 270° (for vertical tabs)
final
rotateTurns int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wrapperModel WrapperModel?
Fully custom styling configuration.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildContent(BuildContext context) Widget
Implement this in subclasses to build the core content of the tab.
buildTab(BuildContext context) Widget
Builds the final Tab with either a custom builder or a factory wrapper.
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
let<T>(T transformation(Widget)) → T?

Available on Widget?, provided by the WidgetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited