buildContent abstract method
Implement this in subclasses to build the core content of the tab.
Implementation
@protected
Widget buildContent(BuildContext context);
Implement this in subclasses to build the core content of the tab.
@protected
Widget buildContent(BuildContext context);