SimpleTab class

A tab that displays an icon and text together. Can be horizontal (icon → text or text → icon) or vertical (icon on top of text).

Inheritance
Available extensions

Constructors

SimpleTab({Key? key, String? label, WrapperModel? wrapperModel, double? height, bool? rotate, int? rotateTurns, IconData? icon, bool iconFirst = true, bool vertical = false, double spacing = 4, double iconSize = 24, TextStyle? textStyle})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
height double?
Custom builder to wrap the child if you don’t want to use wrapperType. Optional height of the tab (passed to the Tab widget).
finalinherited
icon IconData?
final
iconFirst bool
final
iconSize double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
Optional text label for the tab.
finalinherited
rotate bool?
Whether to rotate the tab content 270° (for vertical tabs)
finalinherited
rotateTurns int?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
final
textStyle TextStyle?
final
vertical bool
final
wrapperModel WrapperModel?
Fully custom styling configuration.
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildContent(BuildContext context) Widget
Implement this in subclasses to build the core content of the tab.
override
buildTab(BuildContext context) Widget
Builds the final Tab with either a custom builder or a factory wrapper.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
let<T>(T transformation(Widget)) → T?

Available on Widget?, provided by the WidgetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited