TabBuilder class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
build(
{required TabController controller, List< TabItemModel> ? tabItems, TabType? tabType, bool? rotate, int? rotateTurns, WrapperModel? wrapperModel, List<Widget> ? customTabs, TabAnimationModel animation = const TabAnimationModel()}) → List<Widget>