CardWrapper class

Implemented types

Constructors

CardWrapper({EdgeInsets? margin, Color? backgroundColor, double borderRadius = 8, double elevation = 4, EdgeInsets padding = const EdgeInsets.all(8)})
const

Properties

backgroundColor Color?
final
borderRadius double
final
elevation double
final
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsets?
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(Widget child) Widget
override

Operators

operator ==(Object other) bool
The equality operator.
inherited