GradientWrapper class

Implemented types

Constructors

GradientWrapper({EdgeInsets? margin, EdgeInsets padding = const EdgeInsets.all(8), double borderRadius = 8, Gradient? gradient, List<Color>? gradientColors})
const

Properties

borderRadius double
final
gradient Gradient?
final
gradientColors List<Color>?
final
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsets?
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(Widget child) Widget
override

Operators

operator ==(Object other) bool
The equality operator.
inherited