IWrapper class abstract
Base interface for all wrappers
Constructors
- IWrapper()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
Widget child) → Widget
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited