OutlinedContainerWrapper class

Implemented types

Constructors

OutlinedContainerWrapper({EdgeInsets? margin, EdgeInsets padding = const EdgeInsets.all(8), Color? backgroundColor, Color? borderColor, double borderRadius = 8, BoxShadow? boxShadow, double borderWidth = 1})
const

Properties

backgroundColor Color?
final
borderColor Color?
final
borderRadius double
final
borderWidth double
final
boxShadow BoxShadow?
final
hashCode int
The hash code for this object.
no setterinherited
margin EdgeInsets?
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(Widget child) Widget
override

Operators

operator ==(Object other) bool
The equality operator.
inherited