SegmentedWrapper class

Implemented types

Constructors

SegmentedWrapper({EdgeInsets? margin, EdgeInsets padding = const EdgeInsets.all(8), double borderRadius = 12, Color? backgroundColor, Color? selectedColor, bool isSelected = false})
const

Properties

backgroundColor Color?
final
borderRadius double
final
hashCode int
The hash code for this object.
no setterinherited
isSelected bool
final
margin EdgeInsets?
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedColor Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(Widget child) Widget
override

Operators

operator ==(Object other) bool
The equality operator.
inherited