WrapperModel class
Holds style information for a custom-shaped tab. Optional wrapper styling for the tab itself.
Constructors
- WrapperModel({WrapperType wrapperType = WrapperType.padded, EdgeInsets padding = const EdgeInsets.all(8), EdgeInsets? margin, double borderRadius = 8.0, Color? backgroundColor, Color? borderColor, double? borderWidth, double elevation = 4.0, double blurX = 8.0, double blurY = 8.0, Color? shadowLightColor, Color? shadowDarkColor, Gradient? gradient, Widget customWrapperBuilder(Widget child)?})
-
const
Properties
- backgroundColor → Color?
-
final
- blurX → double
-
final
- blurY → double
-
final
- borderColor → Color?
-
final
- borderRadius → double
-
final
- borderWidth → double?
-
final
- customWrapperBuilder → Widget Function(Widget child)?
-
final
- elevation → double
-
final
- gradient → Gradient?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- margin → EdgeInsets?
-
final
- padding → EdgeInsets
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowDarkColor → Color?
-
final
- shadowLightColor → Color?
-
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - wrapperType → WrapperType
-
final
Methods
-
copyWith(
{WrapperType? wrapperType, EdgeInsets? padding, EdgeInsets? margin, double? borderRadius, Color? backgroundColor, Color? borderColor, double? borderWidth, double? elevation, double? blurX, double? blurY, Color? shadowLightColor, Color? shadowDarkColor, Gradient? gradient}) → WrapperModel - Enables easy state updates
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited